from setuptools import setup


setup(name='jiange',
      version='0.1.0',
      description='functions used by zhanglinjian',
      url='http://github.com/linjian',
      author='Zhang Linjian',
      author_email='zhanglinjian1@gmail.com',
      license='MIT',
      packages=['jiange'],
      zip_safe=False)
